/*
 * Copyright 2017 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.diirt.datasource.internal;

import org.diirt.vtype.VStringArray;

import com.aquenos.epics.jackie.common.value.ChannelAccessTimeString;
import com.aquenos.epics.jackie.common.value.ChannelAccessValueType;
import com.aquenos.epics.jackie.diirt.vtype.JackieVStringArray;

/**
 * Type adapter that convert from {@link ChannelAccessTimeString} to
 * {@link VStringArray}.
 * 
 * @author Sebastian Marsching
 */
public class ArrayStringTypeAdapter
        extends JackieDataSourceTypeAdapter<VStringArray> {

    /**
     * Single instance of this adapter.
     */
    public static final ArrayStringTypeAdapter INSTANCE = new ArrayStringTypeAdapter();

    private ArrayStringTypeAdapter() {
        super(false, ChannelAccessValueType.DBR_STRING, VStringArray.class);
    }

    @Override
    protected VStringArray convertValue(JackieConnectionPayload connection,
            JackieMessagePayload message) {
        // We can safely make a cast here because this adapter is only used if
        // the channel's native type is DBR_STRING and we thus know that the
        // monitor returns a DBR_TIME_STRING.
        ChannelAccessTimeString timeValue = (ChannelAccessTimeString) message
                .getTimeValue();
        return new JackieVStringArray(timeValue,
                connection.getDisconnectTime());
    }

}
