/*
 * Copyright 2017 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.diirt.datasource.internal;

import org.diirt.vtype.VFloat;

import com.aquenos.epics.jackie.common.value.ChannelAccessControlsFloat;
import com.aquenos.epics.jackie.common.value.ChannelAccessTimeFloat;
import com.aquenos.epics.jackie.common.value.ChannelAccessValueType;
import com.aquenos.epics.jackie.diirt.vtype.JackieVFloat;

/**
 * Type adapter that convert from {@link ChannelAccessControlsFloat} and
 * {@link ChannelAccessTimeFloat} to {@link VFloat}. This adapter can only be
 * used if the value has exactly one element.
 * 
 * @author Sebastian Marsching
 */
public class ScalarFloatTypeAdapter
        extends JackieDataSourceTypeAdapter<VFloat> {

    /**
     * Single instance of this adapter.
     */
    public static final ScalarFloatTypeAdapter INSTANCE = new ScalarFloatTypeAdapter();

    private ScalarFloatTypeAdapter() {
        super(true, ChannelAccessValueType.DBR_FLOAT, VFloat.class);
    }

    @Override
    protected VFloat convertValue(JackieConnectionPayload connection,
            JackieMessagePayload message) {
        // We can safely make a cast here because this adapter is only used if
        // the channel's native type is DBR_FLOAT and we thus know that the
        // monitors return a DBR_CTRL_FLOAT and DBR_TIME_FLOAT.
        ChannelAccessControlsFloat controlsValue = (ChannelAccessControlsFloat) message
                .getControlsValue();
        ChannelAccessTimeFloat timeValue = (ChannelAccessTimeFloat) message
                .getTimeValue();
        return new JackieVFloat(controlsValue, timeValue,
                connection.getDisconnectTime(),
                connection.isHonorZeroPrecision());
    }

}
